@@ -37,6 +37,10 @@
 #include <Carbon/Carbon.h>
 #include <gdk/gdkquartz.h>
 
+#else
+
+#include <gdk/gdkx.h>
+
 #endif
 
 #include "xmalloc.h"
@@ -650,16 +654,28 @@ void build_ui()
 	tree_view = GTK_TREE_VIEW(gtk_tree_view_new());
 	gtk_tree_view_set_headers_visible(tree_view, FALSE);
 
-	unsigned display_width, display_height;
-	get_monitor_dimensions(&display_width, &display_height);
-	gtk_widget_set_size_request(GTK_WIDGET(tree_view), display_width/2, display_height/2);
-
 	gtk_tree_view_set_enable_search(tree_view, FALSE);
 	gtk_tree_view_set_fixed_height_mode(tree_view, TRUE);
 	gtk_tree_view_set_show_expanders(tree_view, FALSE);
 	gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(tree_view));
 
+	unsigned display_width, display_height;
+	get_monitor_dimensions(&display_width, &display_height);
+	gtk_window_set_default_size(top_window, display_width/2, display_height/2);
+
+	gtk_window_set_position(top_window, GTK_WIN_POS_CENTER);
+
 	gtk_widget_show_all(GTK_WIDGET(top_window));
+
+	// TODO: detect gdk_x11 at configure time instead of this hack
+#if !defined(__APPLE__) || !defined(__MACH__)
+	gtk_widget_realize(GTK_WIDGET(top_window));
+	// force our popup to be recent enough to display on top
+	GdkWindow *gdk_win = gtk_widget_get_window(GTK_WIDGET(top_window));
+	gdk_x11_window_set_user_time(gdk_win, gdk_x11_get_server_time(gdk_win));
+#endif
+
+	gtk_window_present(top_window);
 }
 
 extern
